@@ -303,5 +303,5 @@ if __name__ == '__main__':
           ]
     l = ["今晚5点", "星期三", "这周三", "这周六", "这周日", "周末", "星期日",
          "明天中午11点", '明天中午12点', '明天中午1点', "明天上午11点"]
-    for text in l:
+    for text in ll:
         print(text, time_extract(text), sep=': ')
